#
# spec file for package ding
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ding
Version:        1.9
Release:        bp156.4.1
Summary:        An X Window System Dictionary Tool
License:        GPL-2.0-or-later
Group:          Productivity/Office/Dictionary
URL:            https://www-user.tu-chemnitz.de/~fri/ding/
Source:         https://ftp.tu-chemnitz.de/pub/Local/urz/%{name}/%{name}-%{version}.tar.gz
Source1:        ding.desktop
Patch0:         ding-install.diff
Patch1:         ding-tk-version.diff
Patch2:         use-grep-instead-of-egrep.patch
BuildRequires:  tk
BuildRequires:  update-desktop-files
Requires:       ding-dict-de_en
Requires:       tcl
Requires:       tk
Recommends:     agrep
Recommends:     ispell
Recommends:     ispell-american
Recommends:     ispell-ngerman
Suggests:       fortune
BuildArch:      noarch

%description
Ding is a graphical frontend to an English-to-German dictionary
lookup and word spell checking. For full functionality, agrep and
ispell should be installed.

%package -n ding-dict-de_en
Summary:        German<->English word dictionary in DING syntax
Group:          Productivity/Office/Dictionary

%description -n ding-dict-de_en
This package contains the German<->English dictionary/wordlist from
TU Chemnitz in an easy markup language suitable for use with grep.
A recommended graphical frontend for using this dictionary is "ding".

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build

%install
mkdir -p "%{buildroot}/%{_bindir}" "%{buildroot}/%{_datadir}/dict" \
	"%{buildroot}/%{_datadir}/applications"
./install.sh <<EOF
%{buildroot}/%{_bindir}
%{buildroot}/%{_datadir}/dict
y
EOF
install -m 644 %{SOURCE1} "%{buildroot}/%{_datadir}/applications/%{name}.desktop"
install -D -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
%suse_update_desktop_file %{name} Office Dictionary

%files
%license COPYING
%doc README.md CHANGES
%{_bindir}/ding
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/ding.1%{?ext_man}

%files -n ding-dict-de_en
%{_datadir}/dict/de-en.txt

%changelog
* Sun Sep 18 2022 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * use-grep-instead-of-egrep.patch
    This prevents the egrep obsolescent warning message introduced
    with grep 3.8:
    "egrep: warning: egrep is obsolescent; using grep -E"
- Install man-page
- Use https instead of http/ftp for Source/URL
* Wed May 12 2021 Daniel Donisa <daniel.donisa@suse.com>
- Update to 1.9
  * Enhanced English-German dictionary (380,000 entries)
  * Bugfixes
* Mon Feb 27 2017 mimi.vx@gmail.com
- fix Source patch, spec-cleaned
* Mon Feb 27 2017 sfalken@opensuse.org
- Update to version 1.8.1:
  * New version of German-English translation file, now over 345,000 entries
  * Minor bug fixes
* Thu Dec 11 2014 jengelh@inai.de
- Update to new upstream release 1.8
  * New version of German-English translation file,
  now over 326,000 entries (up from 270,000).
  * Minor bug fixes.
- Split the dictionary file so as to not mandate installation of
  the Tk frontend.
- Downgrade ispell dictionary requirements into recommendations;
  ding works without them, too.
- Add missing ispell Recommends (just having the dictionaries does
  not help, the program is needed).
- Also recommend agrep, which the Tk frontend prefers for full
  functionality (approximate matching).
- Suggest fortune, because ding even supports searching that.
- Minor cleanups: use rpm macros in place of rpm shell vars.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Fri Nov  5 2010 hvogel@novell.com
- Upodate to version 1.7
  * Copy to clipboard, not just primary selection (Unix)
  * Bugfixes, robustness increased
  * Enhanced English-German dictionary (270,000 entries)
* Wed Aug  5 2009 hvogel@suse.de
- Update to verion 1.6
  - Catch more faulty inputs
  - Update of the dictionary
* Tue Oct 28 2008 coolo@suse.de
- remove quotes from GenericName
* Fri Apr 18 2008 hvogel@suse.de
- Require american/german ispell packages for spellchecking
* Sat Apr 21 2007 bwalle@suse.de
- update to 1.5
  o New version of German-English translation file, now over
    216,000 entries
  o Some more keyboard shortcuts: ^W, ^U
  o bug fix in internal search
  o changed colors when selecting text in result
  o copy to clipboard in popup/file menu
  o remote invoking changes the query entry (Debian bug #292978)
  o internal search mode works again (tcl_nonwordchars)
  o Minor bug fixes (install.sh)
* Sat Apr  7 2007 bwalle@suse.de
- added application icon  (accepted already upstream, but due to
  long release cycles added to the package)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep  5 2005 hvogel@suse.de
- require tk for the wish binary [#115259]
* Mon May  9 2005 hvogel@suse.de
- update to version 1.4
* Thu Mar 18 2004 hvogel@suse.de
- add desktop file (Bug #36504)
- move ding to /usr
* Mon Feb 16 2004 hvogel@suse.de
- update to version 1.3
- in fact ding is noarch
* Thu Nov 13 2003 hvogel@suse.de
- make use of %%defattr in %%files
* Thu Nov 13 2003 hvogel@suse.de
- dont build as root
* Mon May 26 2003 sndirsch@suse.de
- adjusted install.sh for using BuildRoot; ding works again
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug  2 2002 freitag@suse.de
- update to version 1.2
  removed tcl from the neededforbuild and put tcl to requires.
  Moved dictionary file to /usr/share/dicts
* Mon Aug 13 2001 freitag@suse.de
- removed kde1 desktopfiles and made an entry to the database for
  better appearance o the desktop.
  bzipped the source
* Sat Dec  9 2000 nashif@suse.de
- sorted
* Thu May 25 2000 freitag@suse.de
- update to version 1.1
* Mon Feb 28 2000 freitag@suse.de
- Group Tag inserted and ftp-Source
* Tue Dec 14 1999 freitag@suse.de
- initial version 1.0
